==> tomcat9_9.0.115.orig.tar.xz: tomcat9-9.0.115/test/org/apache/tomcat/util/net/ocsp/TestOcspSoftFail.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.tomcat.util.net.ocsp;

import java.net.SocketException;

import javax.net.ssl.SSLHandshakeException;

import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.Parameterized;

/*
 * Only looking to test the Tomcat (server) side configuration of soft fail.
 */
@RunWith(Parameterized.class)
public class TestOcspSoftFail extends OcspBaseTest {

    @Test
    public void testNoResponderDefaultSoftFail() throws Exception {
        // Default behaviour should be the same for all configurations and equivalent to enabled.
        doTest(false, false, ClientCertificateVerification.ENABLED, false, null);
    }


    @Test
    public void testNoResponderWithSoftFail() throws Exception {
        doTest(false, false, ClientCertificateVerification.ENABLED, false, Boolean.TRUE);
    }


    @Test(expected = SSLHandshakeException.class)
    public void testNoResponderWithoutSoftFail() throws Exception {
        try {
            doTest(false, false, ClientCertificateVerification.ENABLED, false, Boolean.FALSE);
        } catch (SocketException se) {
            // APR or NIO2 may throw a SocketException rather than a SSLHandshakeException
            throw new SSLHandshakeException(se.getMessage());
        }
    }
}

==> tomcat10_10.1.52.orig.tar.xz: tomcat10-10.1.52/test/org/apache/tomcat/util/net/ocsp/TestOcspSoftFail.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.tomcat.util.net.ocsp;

import java.net.SocketException;

import javax.net.ssl.SSLHandshakeException;

import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.Parameterized;

/*
 * Only looking to test the Tomcat (server) side configuration of soft fail.
 */
@RunWith(Parameterized.class)
public class TestOcspSoftFail extends OcspBaseTest {

    @Test
    public void testNoResponderDefaultSoftFail() throws Exception {
        // Default behaviour should be the same for all configurations and equivalent to enabled.
        doTest(false, false, ClientCertificateVerification.ENABLED, false, null);
    }


    @Test
    public void testNoResponderWithSoftFail() throws Exception {
        doTest(false, false, ClientCertificateVerification.ENABLED, false, Boolean.TRUE);
    }


    @Test(expected = SSLHandshakeException.class)
    public void testNoResponderWithoutSoftFail() throws Exception {
        try {
            doTest(false, false, ClientCertificateVerification.ENABLED, false, Boolean.FALSE);
        } catch (SocketException se) {
            // NIO2 may throw a SocketException rather than a SSLHandshakeException
            if (getTomcatInstance().getConnector().getProtocolHandlerClassName().contains("Nio2")) {
                throw new SSLHandshakeException(se.getMessage());
            } else {
                throw se;
            }
        }
    }
}
